netapp_ontap.models.security_association_ipsec API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.security_association_ipsec`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SecurityAssociationIpsecSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SecurityAssociationIpsec object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `action GET POST PATCH`

    Action for the IPsec security association.

    Valid choices:

    - bypass
    - discard
    - esp_transport
  `inbound GET POST PATCH`

    The inbound field of the security_association_ipsec.

  `outbound GET POST PATCH`

    The outbound field of the security_association_ipsec.

  `state GET POST PATCH`

    State of the IPsec security association.